<?php
/*
Plugin Name: External Websites Admin Display
Description: Displays multiple external websites in the WordPress Admin Area.
Version: 2.0
Author: Fabio Huwyler
*/

// Register the settings page
function ewad_admin_menu() {
    add_menu_page(
        'External Websites', 
        'External Websites', 
        'manage_options', 
        'external-websites-settings', 
        'ewad_display_options_page'
    );

    $websites = get_option('ewad_websites', []);
    foreach ($websites as $index => $website) {
        $title = esc_html($website['title']);
        // Add submenu for each external website
        add_submenu_page(
            'external-websites-settings',
            $title,
            $title,
            'manage_options',
            'external-website-' . $index,
            function() use ($website) {
                ewad_display_website($website);
            }
        );
    }
}
add_action('admin_menu', 'ewad_admin_menu');

function ewad_display_website($website) {
    $url = esc_url($website['url']);
    if (empty($url)) {
        echo "Please set an external website URL in the settings page.";
        return;
    }
    ?>
    <iframe src="<?php echo $url; ?>" width="100%" style="height:calc(100vh - 32px);" frameborder="0"></iframe>
    <?php
}

function ewad_display_options_page() {
    ?>
    <div class="wrap">
        <h1>External Website Settings</h1>
        <form method="post" action="options.php">
            <?php
                settings_fields('ewad_options_group');
                do_settings_sections('external-websites-settings');
                submit_button();
            ?>
        </form>
        <script>
        function addWebsiteField() {
            var container = document.getElementById('websites-container');
            var newIndex = container.children.length; // This determines the next index for the form field names
            var div = document.createElement('div');
            div.innerHTML = 'Title: <input type="text" name="ewad_websites[' + newIndex + '][title]"> URL: <input type="text" name="ewad_websites[' + newIndex + '][url]"> <button type="button" onclick="this.parentElement.remove()">Remove</button>';
            container.appendChild(div);
        }
        </script>
    </div>
    <?php
}

function ewad_settings_init() {
    register_setting(
        'ewad_options_group',
        'ewad_websites',
        'ewad_websites_sanitize'
    );

    add_settings_section(
        'ewad_settings_section',
        'Settings',
        null,
        'external-websites-settings'
    );

    add_settings_field(
        'ewad_website_field',
        'External Websites',
        'ewad_website_field_callback',
        'external-websites-settings',
        'ewad_settings_section'
    );  
}
add_action('admin_init', 'ewad_settings_init');

function ewad_websites_sanitize($input) {
    $new_input = [];
    foreach ($input as $website) {
        if (!empty(trim($website['url'])) && !empty(trim($website['title']))) {
            $new_input[] = [
                'url' => esc_url_raw($website['url']),
                'title' => sanitize_text_field($website['title'])
            ];
        }
    }
    return $new_input;
}

function ewad_website_field_callback() {
    $websites = get_option('ewad_websites', []);
    echo '<div id="websites-container">';
    foreach ($websites as $index => $website) {
        echo '<div>';
        echo 'Title: <input type="text" name="ewad_websites[' . $index . '][title]" value="' . esc_attr($website['title']) . '">';
        echo 'URL: <input type="text" name="ewad_websites[' . $index . '][url]" value="' . esc_url($website['url']) . '">';
        echo '<button type="button" onclick="this.parentElement.remove()">Remove</button>';
        echo '</div>';
    }
    echo '</div>';
    echo '<button type="button" onclick="addWebsiteField()">Add Website</button>';
}
?>
